@@ -1,7 +1,7 @@
 '''
 # `data_google_billing_account`
 
-Refer to the Terraform Registory for docs: [`data_google_billing_account`](https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_billing_account).
+Refer to the Terraform Registry for docs: [`data_google_billing_account`](https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_billing_account).
 '''
 import abc
 import builtins
@@ -26,7 +26,7 @@ class DataGoogleBillingAccount(
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-google-beta.dataGoogleBillingAccount.DataGoogleBillingAccount",
 ):
-    '''Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_billing_account google_billing_account}.'''
+    '''Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_billing_account google_billing_account}.'''
 
     def __init__(
         self,
@@ -36,6 +36,7 @@ class DataGoogleBillingAccount(
         billing_account: typing.Optional[builtins.str] = None,
         display_name: typing.Optional[builtins.str] = None,
         id: typing.Optional[builtins.str] = None,
+        lookup_projects: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         open: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]] = None,
@@ -45,14 +46,15 @@ class DataGoogleBillingAccount(
         provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
         provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
-        '''Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_billing_account google_billing_account} Data Source.
+        '''Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_billing_account google_billing_account} Data Source.
 
         :param scope: The scope in which to define this construct.
         :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
-        :param billing_account: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_billing_account#billing_account DataGoogleBillingAccount#billing_account}.
-        :param display_name: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_billing_account#display_name DataGoogleBillingAccount#display_name}.
-        :param id: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_billing_account#id DataGoogleBillingAccount#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
-        :param open: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_billing_account#open DataGoogleBillingAccount#open}.
+        :param billing_account: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_billing_account#billing_account DataGoogleBillingAccount#billing_account}.
+        :param display_name: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_billing_account#display_name DataGoogleBillingAccount#display_name}.
+        :param id: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_billing_account#id DataGoogleBillingAccount#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
+        :param lookup_projects: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_billing_account#lookup_projects DataGoogleBillingAccount#lookup_projects}.
+        :param open: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_billing_account#open DataGoogleBillingAccount#open}.
         :param connection: 
         :param count: 
         :param depends_on: 
@@ -69,6 +71,7 @@ class DataGoogleBillingAccount(
             billing_account=billing_account,
             display_name=display_name,
             id=id,
+            lookup_projects=lookup_projects,
             open=open,
             connection=connection,
             count=count,
@@ -81,6 +84,30 @@ class DataGoogleBillingAccount(
 
         jsii.create(self.__class__, self, [scope, id_, config])
 
+    @jsii.member(jsii_name="generateConfigForImport")
+    @builtins.classmethod
+    def generate_config_for_import(
+        cls,
+        scope: _constructs_77d1e7e8.Construct,
+        import_to_id: builtins.str,
+        import_from_id: builtins.str,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    ) -> _cdktf_9a9027ec.ImportableResource:
+        '''Generates CDKTF code for importing a DataGoogleBillingAccount resource upon running "cdktf plan ".
+
+        :param scope: The scope in which to define this construct.
+        :param import_to_id: The construct id used in the generated config for the DataGoogleBillingAccount to import.
+        :param import_from_id: The id of the existing DataGoogleBillingAccount that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_billing_account#import import section} in the documentation of this resource for the id to use
+        :param provider: ? Optional instance of the provider where the DataGoogleBillingAccount to import is found.
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__7a0930badad435c4ad541e480431f1d0cdec483092ad1ea5addefcdf1acf57c2)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument import_to_id", value=import_to_id, expected_type=type_hints["import_to_id"])
+            check_type(argname="argument import_from_id", value=import_from_id, expected_type=type_hints["import_from_id"])
+            check_type(argname="argument provider", value=provider, expected_type=type_hints["provider"])
+        return typing.cast(_cdktf_9a9027ec.ImportableResource, jsii.sinvoke(cls, "generateConfigForImport", [scope, import_to_id, import_from_id, provider]))
+
     @jsii.member(jsii_name="resetBillingAccount")
     def reset_billing_account(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetBillingAccount", []))
@@ -93,6 +120,10 @@ class DataGoogleBillingAccount(
     def reset_id(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetId", []))
 
+    @jsii.member(jsii_name="resetLookupProjects")
+    def reset_lookup_projects(self) -> None:
+        return typing.cast(None, jsii.invoke(self, "resetLookupProjects", []))
+
     @jsii.member(jsii_name="resetOpen")
     def reset_open(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetOpen", []))
@@ -101,6 +132,10 @@ class DataGoogleBillingAccount(
     def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))
 
+    @jsii.member(jsii_name="synthesizeHclAttributes")
+    def _synthesize_hcl_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
+        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeHclAttributes", []))
+
     @jsii.python.classproperty
     @jsii.member(jsii_name="tfResourceType")
     def TF_RESOURCE_TYPE(cls) -> builtins.str:
@@ -131,6 +166,13 @@ class DataGoogleBillingAccount(
     def id_input(self) -> typing.Optional[builtins.str]:
         return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))
 
+    @builtins.property
+    @jsii.member(jsii_name="lookupProjectsInput")
+    def lookup_projects_input(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "lookupProjectsInput"))
+
     @builtins.property
     @jsii.member(jsii_name="openInput")
     def open_input(
@@ -174,6 +216,23 @@ class DataGoogleBillingAccount(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
+    @builtins.property
+    @jsii.member(jsii_name="lookupProjects")
+    def lookup_projects(
+        self,
+    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "lookupProjects"))
+
+    @lookup_projects.setter
+    def lookup_projects(
+        self,
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+    ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__cef919a9ba5e093f8dee7d57ecbb9fcd4a8181192104464d497d79703a541849)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "lookupProjects", value)
+
     @builtins.property
     @jsii.member(jsii_name="open")
     def open(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
@@ -204,6 +263,7 @@ class DataGoogleBillingAccount(
         "billing_account": "billingAccount",
         "display_name": "displayName",
         "id": "id",
+        "lookup_projects": "lookupProjects",
         "open": "open",
     },
 )
@@ -221,6 +281,7 @@ class DataGoogleBillingAccountConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         billing_account: typing.Optional[builtins.str] = None,
         display_name: typing.Optional[builtins.str] = None,
         id: typing.Optional[builtins.str] = None,
+        lookup_projects: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         open: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
     ) -> None:
         '''
@@ -231,10 +292,11 @@ class DataGoogleBillingAccountConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         :param lifecycle: 
         :param provider: 
         :param provisioners: 
-        :param billing_account: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_billing_account#billing_account DataGoogleBillingAccount#billing_account}.
-        :param display_name: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_billing_account#display_name DataGoogleBillingAccount#display_name}.
-        :param id: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_billing_account#id DataGoogleBillingAccount#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
-        :param open: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_billing_account#open DataGoogleBillingAccount#open}.
+        :param billing_account: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_billing_account#billing_account DataGoogleBillingAccount#billing_account}.
+        :param display_name: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_billing_account#display_name DataGoogleBillingAccount#display_name}.
+        :param id: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_billing_account#id DataGoogleBillingAccount#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
+        :param lookup_projects: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_billing_account#lookup_projects DataGoogleBillingAccount#lookup_projects}.
+        :param open: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_billing_account#open DataGoogleBillingAccount#open}.
         '''
         if isinstance(lifecycle, dict):
             lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
@@ -250,6 +312,7 @@ class DataGoogleBillingAccountConfig(_cdktf_9a9027ec.TerraformMetaArguments):
             check_type(argname="argument billing_account", value=billing_account, expected_type=type_hints["billing_account"])
             check_type(argname="argument display_name", value=display_name, expected_type=type_hints["display_name"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument lookup_projects", value=lookup_projects, expected_type=type_hints["lookup_projects"])
             check_type(argname="argument open", value=open, expected_type=type_hints["open"])
         self._values: typing.Dict[builtins.str, typing.Any] = {}
         if connection is not None:
@@ -272,6 +335,8 @@ class DataGoogleBillingAccountConfig(_cdktf_9a9027ec.TerraformMetaArguments):
             self._values["display_name"] = display_name
         if id is not None:
             self._values["id"] = id
+        if lookup_projects is not None:
+            self._values["lookup_projects"] = lookup_projects
         if open is not None:
             self._values["open"] = open
 
@@ -341,19 +406,19 @@ class DataGoogleBillingAccountConfig(_cdktf_9a9027ec.TerraformMetaArguments):
 
     @builtins.property
     def billing_account(self) -> typing.Optional[builtins.str]:
-        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_billing_account#billing_account DataGoogleBillingAccount#billing_account}.'''
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_billing_account#billing_account DataGoogleBillingAccount#billing_account}.'''
         result = self._values.get("billing_account")
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
     def display_name(self) -> typing.Optional[builtins.str]:
-        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_billing_account#display_name DataGoogleBillingAccount#display_name}.'''
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_billing_account#display_name DataGoogleBillingAccount#display_name}.'''
         result = self._values.get("display_name")
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
     def id(self) -> typing.Optional[builtins.str]:
-        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_billing_account#id DataGoogleBillingAccount#id}.
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_billing_account#id DataGoogleBillingAccount#id}.
 
         Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
         If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
@@ -361,11 +426,19 @@ class DataGoogleBillingAccountConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         result = self._values.get("id")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def lookup_projects(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_billing_account#lookup_projects DataGoogleBillingAccount#lookup_projects}.'''
+        result = self._values.get("lookup_projects")
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
+
     @builtins.property
     def open(
         self,
     ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
-        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_billing_account#open DataGoogleBillingAccount#open}.'''
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_billing_account#open DataGoogleBillingAccount#open}.'''
         result = self._values.get("open")
         return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
@@ -395,6 +468,7 @@ def _typecheckingstub__7cf59af91becc93b1e1220460bee4e1c13cdb559bf46cddfa8abd21e8
     billing_account: typing.Optional[builtins.str] = None,
     display_name: typing.Optional[builtins.str] = None,
     id: typing.Optional[builtins.str] = None,
+    lookup_projects: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
     open: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
     connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
     count: typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]] = None,
@@ -407,6 +481,15 @@ def _typecheckingstub__7cf59af91becc93b1e1220460bee4e1c13cdb559bf46cddfa8abd21e8
     """Type checking stubs"""
     pass
 
+def _typecheckingstub__7a0930badad435c4ad541e480431f1d0cdec483092ad1ea5addefcdf1acf57c2(
+    scope: _constructs_77d1e7e8.Construct,
+    import_to_id: builtins.str,
+    import_from_id: builtins.str,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
 def _typecheckingstub__4d1595d1d9200eda056d15d03cc27f357ca570c65db7dfa3f49eeb2661f12bfb(
     value: builtins.str,
 ) -> None:
@@ -425,6 +508,12 @@ def _typecheckingstub__48751fe52d991fe4c85af2f2f6421c4fb808376366ad7e157464753cf
     """Type checking stubs"""
     pass
 
+def _typecheckingstub__cef919a9ba5e093f8dee7d57ecbb9fcd4a8181192104464d497d79703a541849(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
 def _typecheckingstub__8291c2041c88f616f083682464d17a7f4df22cbdfaa5130c525f2495cd57f35a(
     value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
 ) -> None:
@@ -443,6 +532,7 @@ def _typecheckingstub__30b446610b9f057ae017bea072afcdb50f3850d7c3b90cdcef128f03f
     billing_account: typing.Optional[builtins.str] = None,
     display_name: typing.Optional[builtins.str] = None,
     id: typing.Optional[builtins.str] = None,
+    lookup_projects: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
     open: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
 ) -> None:
     """Type checking stubs"""
