@@ -1,7 +1,7 @@
 '''
 # `data_google_iam_policy`
 
-Refer to the Terraform Registory for docs: [`data_google_iam_policy`](https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy).
+Refer to the Terraform Registry for docs: [`data_google_iam_policy`](https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy).
 '''
 import abc
 import builtins
@@ -26,7 +26,7 @@ class DataGoogleIamPolicy(
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-google-beta.dataGoogleIamPolicy.DataGoogleIamPolicy",
 ):
-    '''Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy google_iam_policy}.'''
+    '''Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy google_iam_policy}.'''
 
     def __init__(
         self,
@@ -44,13 +44,13 @@ class DataGoogleIamPolicy(
         provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
         provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
-        '''Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy google_iam_policy} Data Source.
+        '''Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy google_iam_policy} Data Source.
 
         :param scope: The scope in which to define this construct.
         :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
-        :param audit_config: audit_config block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#audit_config DataGoogleIamPolicy#audit_config}
-        :param binding: binding block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#binding DataGoogleIamPolicy#binding}
-        :param id: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#id DataGoogleIamPolicy#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
+        :param audit_config: audit_config block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#audit_config DataGoogleIamPolicy#audit_config}
+        :param binding: binding block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#binding DataGoogleIamPolicy#binding}
+        :param id: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#id DataGoogleIamPolicy#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
         :param connection: 
         :param count: 
         :param depends_on: 
@@ -78,6 +78,30 @@ class DataGoogleIamPolicy(
 
         jsii.create(self.__class__, self, [scope, id_, config])
 
+    @jsii.member(jsii_name="generateConfigForImport")
+    @builtins.classmethod
+    def generate_config_for_import(
+        cls,
+        scope: _constructs_77d1e7e8.Construct,
+        import_to_id: builtins.str,
+        import_from_id: builtins.str,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    ) -> _cdktf_9a9027ec.ImportableResource:
+        '''Generates CDKTF code for importing a DataGoogleIamPolicy resource upon running "cdktf plan ".
+
+        :param scope: The scope in which to define this construct.
+        :param import_to_id: The construct id used in the generated config for the DataGoogleIamPolicy to import.
+        :param import_from_id: The id of the existing DataGoogleIamPolicy that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#import import section} in the documentation of this resource for the id to use
+        :param provider: ? Optional instance of the provider where the DataGoogleIamPolicy to import is found.
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__809e18fad6f93e3c0576e3aa3e9c44e955cf20ad2f9e7e1c1863ea404e524714)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument import_to_id", value=import_to_id, expected_type=type_hints["import_to_id"])
+            check_type(argname="argument import_from_id", value=import_from_id, expected_type=type_hints["import_from_id"])
+            check_type(argname="argument provider", value=provider, expected_type=type_hints["provider"])
+        return typing.cast(_cdktf_9a9027ec.ImportableResource, jsii.sinvoke(cls, "generateConfigForImport", [scope, import_to_id, import_from_id, provider]))
+
     @jsii.member(jsii_name="putAuditConfig")
     def put_audit_config(
         self,
@@ -120,6 +144,10 @@ class DataGoogleIamPolicy(
     def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))
 
+    @jsii.member(jsii_name="synthesizeHclAttributes")
+    def _synthesize_hcl_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
+        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeHclAttributes", []))
+
     @jsii.python.classproperty
     @jsii.member(jsii_name="tfResourceType")
     def TF_RESOURCE_TYPE(cls) -> builtins.str:
@@ -185,8 +213,8 @@ class DataGoogleIamPolicyAuditConfig:
         service: builtins.str,
     ) -> None:
         '''
-        :param audit_log_configs: audit_log_configs block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#audit_log_configs DataGoogleIamPolicy#audit_log_configs}
-        :param service: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#service DataGoogleIamPolicy#service}.
+        :param audit_log_configs: audit_log_configs block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#audit_log_configs DataGoogleIamPolicy#audit_log_configs}
+        :param service: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#service DataGoogleIamPolicy#service}.
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__28798e828a7e83a8aadc57aa10b90dcbe713dc1edcfe64d6475fe459657cccec)
@@ -203,7 +231,7 @@ class DataGoogleIamPolicyAuditConfig:
     ) -> typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["DataGoogleIamPolicyAuditConfigAuditLogConfigs"]]:
         '''audit_log_configs block.
 
-        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#audit_log_configs DataGoogleIamPolicy#audit_log_configs}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#audit_log_configs DataGoogleIamPolicy#audit_log_configs}
         '''
         result = self._values.get("audit_log_configs")
         assert result is not None, "Required property 'audit_log_configs' is missing"
@@ -211,7 +239,7 @@ class DataGoogleIamPolicyAuditConfig:
 
     @builtins.property
     def service(self) -> builtins.str:
-        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#service DataGoogleIamPolicy#service}.'''
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#service DataGoogleIamPolicy#service}.'''
         result = self._values.get("service")
         assert result is not None, "Required property 'service' is missing"
         return typing.cast(builtins.str, result)
@@ -241,8 +269,8 @@ class DataGoogleIamPolicyAuditConfigAuditLogConfigs:
         exempted_members: typing.Optional[typing.Sequence[builtins.str]] = None,
     ) -> None:
         '''
-        :param log_type: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#log_type DataGoogleIamPolicy#log_type}.
-        :param exempted_members: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#exempted_members DataGoogleIamPolicy#exempted_members}.
+        :param log_type: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#log_type DataGoogleIamPolicy#log_type}.
+        :param exempted_members: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#exempted_members DataGoogleIamPolicy#exempted_members}.
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__9b46d149e1590446ff48468f9893e4220d0a6ffdcbd548c6423b3519c554da8c)
@@ -256,14 +284,14 @@ class DataGoogleIamPolicyAuditConfigAuditLogConfigs:
 
     @builtins.property
     def log_type(self) -> builtins.str:
-        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#log_type DataGoogleIamPolicy#log_type}.'''
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#log_type DataGoogleIamPolicy#log_type}.'''
         result = self._values.get("log_type")
         assert result is not None, "Required property 'log_type' is missing"
         return typing.cast(builtins.str, result)
 
     @builtins.property
     def exempted_members(self) -> typing.Optional[typing.List[builtins.str]]:
-        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#exempted_members DataGoogleIamPolicy#exempted_members}.'''
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#exempted_members DataGoogleIamPolicy#exempted_members}.'''
         result = self._values.get("exempted_members")
         return typing.cast(typing.Optional[typing.List[builtins.str]], result)
 
@@ -440,13 +468,13 @@ class DataGoogleIamPolicyAuditConfigAuditLogConfigsOutputReference(
     @jsii.member(jsii_name="internalValue")
     def internal_value(
         self,
-    ) -> typing.Optional[typing.Union[DataGoogleIamPolicyAuditConfigAuditLogConfigs, _cdktf_9a9027ec.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[DataGoogleIamPolicyAuditConfigAuditLogConfigs, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "internalValue"))
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DataGoogleIamPolicyAuditConfigAuditLogConfigs]]:
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DataGoogleIamPolicyAuditConfigAuditLogConfigs]], jsii.get(self, "internalValue"))
 
     @internal_value.setter
     def internal_value(
         self,
-        value: typing.Optional[typing.Union[DataGoogleIamPolicyAuditConfigAuditLogConfigs, _cdktf_9a9027ec.IResolvable]],
+        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DataGoogleIamPolicyAuditConfigAuditLogConfigs]],
     ) -> None:
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__573a5e79b91782cf5969734693898bb844570620a963cebe487fff721291d28c)
@@ -619,13 +647,13 @@ class DataGoogleIamPolicyAuditConfigOutputReference(
     @jsii.member(jsii_name="internalValue")
     def internal_value(
         self,
-    ) -> typing.Optional[typing.Union[DataGoogleIamPolicyAuditConfig, _cdktf_9a9027ec.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[DataGoogleIamPolicyAuditConfig, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "internalValue"))
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DataGoogleIamPolicyAuditConfig]]:
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DataGoogleIamPolicyAuditConfig]], jsii.get(self, "internalValue"))
 
     @internal_value.setter
     def internal_value(
         self,
-        value: typing.Optional[typing.Union[DataGoogleIamPolicyAuditConfig, _cdktf_9a9027ec.IResolvable]],
+        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DataGoogleIamPolicyAuditConfig]],
     ) -> None:
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__edd7aecf7ca6a2e490c20cc477a64cd98633e20b3bd7586e2e432f9f708b3bbf)
@@ -647,9 +675,9 @@ class DataGoogleIamPolicyBinding:
         condition: typing.Optional[typing.Union["DataGoogleIamPolicyBindingCondition", typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
-        :param members: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#members DataGoogleIamPolicy#members}.
-        :param role: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#role DataGoogleIamPolicy#role}.
-        :param condition: condition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#condition DataGoogleIamPolicy#condition}
+        :param members: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#members DataGoogleIamPolicy#members}.
+        :param role: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#role DataGoogleIamPolicy#role}.
+        :param condition: condition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#condition DataGoogleIamPolicy#condition}
         '''
         if isinstance(condition, dict):
             condition = DataGoogleIamPolicyBindingCondition(**condition)
@@ -667,14 +695,14 @@ class DataGoogleIamPolicyBinding:
 
     @builtins.property
     def members(self) -> typing.List[builtins.str]:
-        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#members DataGoogleIamPolicy#members}.'''
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#members DataGoogleIamPolicy#members}.'''
         result = self._values.get("members")
         assert result is not None, "Required property 'members' is missing"
         return typing.cast(typing.List[builtins.str], result)
 
     @builtins.property
     def role(self) -> builtins.str:
-        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#role DataGoogleIamPolicy#role}.'''
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#role DataGoogleIamPolicy#role}.'''
         result = self._values.get("role")
         assert result is not None, "Required property 'role' is missing"
         return typing.cast(builtins.str, result)
@@ -683,7 +711,7 @@ class DataGoogleIamPolicyBinding:
     def condition(self) -> typing.Optional["DataGoogleIamPolicyBindingCondition"]:
         '''condition block.
 
-        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#condition DataGoogleIamPolicy#condition}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#condition DataGoogleIamPolicy#condition}
         '''
         result = self._values.get("condition")
         return typing.cast(typing.Optional["DataGoogleIamPolicyBindingCondition"], result)
@@ -718,9 +746,9 @@ class DataGoogleIamPolicyBindingCondition:
         description: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
-        :param expression: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#expression DataGoogleIamPolicy#expression}.
-        :param title: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#title DataGoogleIamPolicy#title}.
-        :param description: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#description DataGoogleIamPolicy#description}.
+        :param expression: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#expression DataGoogleIamPolicy#expression}.
+        :param title: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#title DataGoogleIamPolicy#title}.
+        :param description: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#description DataGoogleIamPolicy#description}.
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__cf07b488851839d6955b22bd9497e263ca13fae6937868e9e08d48907ceab7dd)
@@ -736,21 +764,21 @@ class DataGoogleIamPolicyBindingCondition:
 
     @builtins.property
     def expression(self) -> builtins.str:
-        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#expression DataGoogleIamPolicy#expression}.'''
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#expression DataGoogleIamPolicy#expression}.'''
         result = self._values.get("expression")
         assert result is not None, "Required property 'expression' is missing"
         return typing.cast(builtins.str, result)
 
     @builtins.property
     def title(self) -> builtins.str:
-        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#title DataGoogleIamPolicy#title}.'''
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#title DataGoogleIamPolicy#title}.'''
         result = self._values.get("title")
         assert result is not None, "Required property 'title' is missing"
         return typing.cast(builtins.str, result)
 
     @builtins.property
     def description(self) -> typing.Optional[builtins.str]:
-        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#description DataGoogleIamPolicy#description}.'''
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#description DataGoogleIamPolicy#description}.'''
         result = self._values.get("description")
         return typing.cast(typing.Optional[builtins.str], result)
 
@@ -982,9 +1010,9 @@ class DataGoogleIamPolicyBindingOutputReference(
         description: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
-        :param expression: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#expression DataGoogleIamPolicy#expression}.
-        :param title: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#title DataGoogleIamPolicy#title}.
-        :param description: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#description DataGoogleIamPolicy#description}.
+        :param expression: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#expression DataGoogleIamPolicy#expression}.
+        :param title: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#title DataGoogleIamPolicy#title}.
+        :param description: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#description DataGoogleIamPolicy#description}.
         '''
         value = DataGoogleIamPolicyBindingCondition(
             expression=expression, title=title, description=description
@@ -1044,13 +1072,13 @@ class DataGoogleIamPolicyBindingOutputReference(
     @jsii.member(jsii_name="internalValue")
     def internal_value(
         self,
-    ) -> typing.Optional[typing.Union[DataGoogleIamPolicyBinding, _cdktf_9a9027ec.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[DataGoogleIamPolicyBinding, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "internalValue"))
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DataGoogleIamPolicyBinding]]:
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DataGoogleIamPolicyBinding]], jsii.get(self, "internalValue"))
 
     @internal_value.setter
     def internal_value(
         self,
-        value: typing.Optional[typing.Union[DataGoogleIamPolicyBinding, _cdktf_9a9027ec.IResolvable]],
+        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DataGoogleIamPolicyBinding]],
     ) -> None:
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__fbd00a0c1be3ef211bb2c4e9408c411237e0d409dc67b83006b4c0ed5d2ee70b)
@@ -1097,9 +1125,9 @@ class DataGoogleIamPolicyConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         :param lifecycle: 
         :param provider: 
         :param provisioners: 
-        :param audit_config: audit_config block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#audit_config DataGoogleIamPolicy#audit_config}
-        :param binding: binding block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#binding DataGoogleIamPolicy#binding}
-        :param id: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#id DataGoogleIamPolicy#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
+        :param audit_config: audit_config block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#audit_config DataGoogleIamPolicy#audit_config}
+        :param binding: binding block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#binding DataGoogleIamPolicy#binding}
+        :param id: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#id DataGoogleIamPolicy#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
         '''
         if isinstance(lifecycle, dict):
             lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
@@ -1207,7 +1235,7 @@ class DataGoogleIamPolicyConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[DataGoogleIamPolicyAuditConfig]]]:
         '''audit_config block.
 
-        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#audit_config DataGoogleIamPolicy#audit_config}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#audit_config DataGoogleIamPolicy#audit_config}
         '''
         result = self._values.get("audit_config")
         return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[DataGoogleIamPolicyAuditConfig]]], result)
@@ -1218,14 +1246,14 @@ class DataGoogleIamPolicyConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[DataGoogleIamPolicyBinding]]]:
         '''binding block.
 
-        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#binding DataGoogleIamPolicy#binding}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#binding DataGoogleIamPolicy#binding}
         '''
         result = self._values.get("binding")
         return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[DataGoogleIamPolicyBinding]]], result)
 
     @builtins.property
     def id(self) -> typing.Optional[builtins.str]:
-        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_policy#id DataGoogleIamPolicy#id}.
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_policy#id DataGoogleIamPolicy#id}.
 
         Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
         If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
@@ -1281,6 +1309,15 @@ def _typecheckingstub__e8abfd021bed39821bb1fa932998e99bb4405434dfa2af19ae5cc26a8
     """Type checking stubs"""
     pass
 
+def _typecheckingstub__809e18fad6f93e3c0576e3aa3e9c44e955cf20ad2f9e7e1c1863ea404e524714(
+    scope: _constructs_77d1e7e8.Construct,
+    import_to_id: builtins.str,
+    import_from_id: builtins.str,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
 def _typecheckingstub__97cd4e7e51929017366e7ed9cb771439284d236afa55e3cde4af686ee003009f(
     value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[DataGoogleIamPolicyAuditConfig, typing.Dict[builtins.str, typing.Any]]]],
 ) -> None:
@@ -1375,7 +1412,7 @@ def _typecheckingstub__5cdd5894137c8b241a6faf70d13e7800b732286d898ff1a510ba848f7
     pass
 
 def _typecheckingstub__573a5e79b91782cf5969734693898bb844570620a963cebe487fff721291d28c(
-    value: typing.Optional[typing.Union[DataGoogleIamPolicyAuditConfigAuditLogConfigs, _cdktf_9a9027ec.IResolvable]],
+    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DataGoogleIamPolicyAuditConfigAuditLogConfigs]],
 ) -> None:
     """Type checking stubs"""
     pass
@@ -1440,7 +1477,7 @@ def _typecheckingstub__8ce7b549e0e59aa2a9bbca742ace37d473c5e8c895859e35de194b50c
     pass
 
 def _typecheckingstub__edd7aecf7ca6a2e490c20cc477a64cd98633e20b3bd7586e2e432f9f708b3bbf(
-    value: typing.Optional[typing.Union[DataGoogleIamPolicyAuditConfig, _cdktf_9a9027ec.IResolvable]],
+    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DataGoogleIamPolicyAuditConfig]],
 ) -> None:
     """Type checking stubs"""
     pass
@@ -1554,7 +1591,7 @@ def _typecheckingstub__9d5494c0280f32b911b6fb9e3852c475a194a6e2bb1ef576d66daf197
     pass
 
 def _typecheckingstub__fbd00a0c1be3ef211bb2c4e9408c411237e0d409dc67b83006b4c0ed5d2ee70b(
-    value: typing.Optional[typing.Union[DataGoogleIamPolicyBinding, _cdktf_9a9027ec.IResolvable]],
+    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DataGoogleIamPolicyBinding]],
 ) -> None:
     """Type checking stubs"""
     pass
