@@ -1,7 +1,7 @@
 '''
 # `data_google_iam_testable_permissions`
 
-Refer to the Terraform Registory for docs: [`data_google_iam_testable_permissions`](https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_testable_permissions).
+Refer to the Terraform Registry for docs: [`data_google_iam_testable_permissions`](https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_testable_permissions).
 '''
 import abc
 import builtins
@@ -26,7 +26,7 @@ class DataGoogleIamTestablePermissions(
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-google-beta.dataGoogleIamTestablePermissions.DataGoogleIamTestablePermissions",
 ):
-    '''Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_testable_permissions google_iam_testable_permissions}.'''
+    '''Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_testable_permissions google_iam_testable_permissions}.'''
 
     def __init__(
         self,
@@ -45,14 +45,14 @@ class DataGoogleIamTestablePermissions(
         provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
         provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
-        '''Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_testable_permissions google_iam_testable_permissions} Data Source.
+        '''Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_testable_permissions google_iam_testable_permissions} Data Source.
 
         :param scope: The scope in which to define this construct.
         :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
-        :param full_resource_name: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_testable_permissions#full_resource_name DataGoogleIamTestablePermissions#full_resource_name}.
-        :param custom_support_level: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_testable_permissions#custom_support_level DataGoogleIamTestablePermissions#custom_support_level}.
-        :param id: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_testable_permissions#id DataGoogleIamTestablePermissions#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
-        :param stages: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_testable_permissions#stages DataGoogleIamTestablePermissions#stages}.
+        :param full_resource_name: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_testable_permissions#full_resource_name DataGoogleIamTestablePermissions#full_resource_name}.
+        :param custom_support_level: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_testable_permissions#custom_support_level DataGoogleIamTestablePermissions#custom_support_level}.
+        :param id: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_testable_permissions#id DataGoogleIamTestablePermissions#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
+        :param stages: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_testable_permissions#stages DataGoogleIamTestablePermissions#stages}.
         :param connection: 
         :param count: 
         :param depends_on: 
@@ -81,6 +81,30 @@ class DataGoogleIamTestablePermissions(
 
         jsii.create(self.__class__, self, [scope, id_, config])
 
+    @jsii.member(jsii_name="generateConfigForImport")
+    @builtins.classmethod
+    def generate_config_for_import(
+        cls,
+        scope: _constructs_77d1e7e8.Construct,
+        import_to_id: builtins.str,
+        import_from_id: builtins.str,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    ) -> _cdktf_9a9027ec.ImportableResource:
+        '''Generates CDKTF code for importing a DataGoogleIamTestablePermissions resource upon running "cdktf plan ".
+
+        :param scope: The scope in which to define this construct.
+        :param import_to_id: The construct id used in the generated config for the DataGoogleIamTestablePermissions to import.
+        :param import_from_id: The id of the existing DataGoogleIamTestablePermissions that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_testable_permissions#import import section} in the documentation of this resource for the id to use
+        :param provider: ? Optional instance of the provider where the DataGoogleIamTestablePermissions to import is found.
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__ab8e910171231c1e68ef7e37d812a58356436827e72f5ddd7a79f874a8f934c0)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument import_to_id", value=import_to_id, expected_type=type_hints["import_to_id"])
+            check_type(argname="argument import_from_id", value=import_from_id, expected_type=type_hints["import_from_id"])
+            check_type(argname="argument provider", value=provider, expected_type=type_hints["provider"])
+        return typing.cast(_cdktf_9a9027ec.ImportableResource, jsii.sinvoke(cls, "generateConfigForImport", [scope, import_to_id, import_from_id, provider]))
+
     @jsii.member(jsii_name="resetCustomSupportLevel")
     def reset_custom_support_level(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetCustomSupportLevel", []))
@@ -97,6 +121,10 @@ class DataGoogleIamTestablePermissions(
     def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))
 
+    @jsii.member(jsii_name="synthesizeHclAttributes")
+    def _synthesize_hcl_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
+        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeHclAttributes", []))
+
     @jsii.python.classproperty
     @jsii.member(jsii_name="tfResourceType")
     def TF_RESOURCE_TYPE(cls) -> builtins.str:
@@ -217,10 +245,10 @@ class DataGoogleIamTestablePermissionsConfig(_cdktf_9a9027ec.TerraformMetaArgume
         :param lifecycle: 
         :param provider: 
         :param provisioners: 
-        :param full_resource_name: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_testable_permissions#full_resource_name DataGoogleIamTestablePermissions#full_resource_name}.
-        :param custom_support_level: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_testable_permissions#custom_support_level DataGoogleIamTestablePermissions#custom_support_level}.
-        :param id: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_testable_permissions#id DataGoogleIamTestablePermissions#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
-        :param stages: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_testable_permissions#stages DataGoogleIamTestablePermissions#stages}.
+        :param full_resource_name: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_testable_permissions#full_resource_name DataGoogleIamTestablePermissions#full_resource_name}.
+        :param custom_support_level: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_testable_permissions#custom_support_level DataGoogleIamTestablePermissions#custom_support_level}.
+        :param id: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_testable_permissions#id DataGoogleIamTestablePermissions#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
+        :param stages: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_testable_permissions#stages DataGoogleIamTestablePermissions#stages}.
         '''
         if isinstance(lifecycle, dict):
             lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
@@ -327,20 +355,20 @@ class DataGoogleIamTestablePermissionsConfig(_cdktf_9a9027ec.TerraformMetaArgume
 
     @builtins.property
     def full_resource_name(self) -> builtins.str:
-        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_testable_permissions#full_resource_name DataGoogleIamTestablePermissions#full_resource_name}.'''
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_testable_permissions#full_resource_name DataGoogleIamTestablePermissions#full_resource_name}.'''
         result = self._values.get("full_resource_name")
         assert result is not None, "Required property 'full_resource_name' is missing"
         return typing.cast(builtins.str, result)
 
     @builtins.property
     def custom_support_level(self) -> typing.Optional[builtins.str]:
-        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_testable_permissions#custom_support_level DataGoogleIamTestablePermissions#custom_support_level}.'''
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_testable_permissions#custom_support_level DataGoogleIamTestablePermissions#custom_support_level}.'''
         result = self._values.get("custom_support_level")
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
     def id(self) -> typing.Optional[builtins.str]:
-        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_testable_permissions#id DataGoogleIamTestablePermissions#id}.
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_testable_permissions#id DataGoogleIamTestablePermissions#id}.
 
         Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
         If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
@@ -350,7 +378,7 @@ class DataGoogleIamTestablePermissionsConfig(_cdktf_9a9027ec.TerraformMetaArgume
 
     @builtins.property
     def stages(self) -> typing.Optional[typing.List[builtins.str]]:
-        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_iam_testable_permissions#stages DataGoogleIamTestablePermissions#stages}.'''
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_iam_testable_permissions#stages DataGoogleIamTestablePermissions#stages}.'''
         result = self._values.get("stages")
         return typing.cast(typing.Optional[typing.List[builtins.str]], result)
 
@@ -561,6 +589,15 @@ def _typecheckingstub__8cacad4a643d1bc61f60994c55e6fc321f1bed5b77a64ce9b63f6648a
     """Type checking stubs"""
     pass
 
+def _typecheckingstub__ab8e910171231c1e68ef7e37d812a58356436827e72f5ddd7a79f874a8f934c0(
+    scope: _constructs_77d1e7e8.Construct,
+    import_to_id: builtins.str,
+    import_from_id: builtins.str,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
 def _typecheckingstub__a6e35b486d328afaaf106a89071be0443dfb264b507b2bb42b287efea91becdb(
     value: builtins.str,
 ) -> None:
