@@ -1,7 +1,7 @@
 '''
 # `data_google_service_account_jwt`
 
-Refer to the Terraform Registory for docs: [`data_google_service_account_jwt`](https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_service_account_jwt).
+Refer to the Terraform Registry for docs: [`data_google_service_account_jwt`](https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_service_account_jwt).
 '''
 import abc
 import builtins
@@ -26,7 +26,7 @@ class DataGoogleServiceAccountJwt(
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-google-beta.dataGoogleServiceAccountJwt.DataGoogleServiceAccountJwt",
 ):
-    '''Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_service_account_jwt google_service_account_jwt}.'''
+    '''Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_service_account_jwt google_service_account_jwt}.'''
 
     def __init__(
         self,
@@ -46,15 +46,15 @@ class DataGoogleServiceAccountJwt(
         provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
         provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
-        '''Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_service_account_jwt google_service_account_jwt} Data Source.
+        '''Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_service_account_jwt google_service_account_jwt} Data Source.
 
         :param scope: The scope in which to define this construct.
         :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
-        :param payload: A JSON-encoded JWT claims set that will be included in the signed JWT. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_service_account_jwt#payload DataGoogleServiceAccountJwt#payload}
-        :param target_service_account: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_service_account_jwt#target_service_account DataGoogleServiceAccountJwt#target_service_account}.
-        :param delegates: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_service_account_jwt#delegates DataGoogleServiceAccountJwt#delegates}.
-        :param expires_in: Number of seconds until the JWT expires. If set and non-zero an ``exp`` claim will be added to the payload derived from the current timestamp plus expires_in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_service_account_jwt#expires_in DataGoogleServiceAccountJwt#expires_in}
-        :param id: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_service_account_jwt#id DataGoogleServiceAccountJwt#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
+        :param payload: A JSON-encoded JWT claims set that will be included in the signed JWT. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_service_account_jwt#payload DataGoogleServiceAccountJwt#payload}
+        :param target_service_account: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_service_account_jwt#target_service_account DataGoogleServiceAccountJwt#target_service_account}.
+        :param delegates: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_service_account_jwt#delegates DataGoogleServiceAccountJwt#delegates}.
+        :param expires_in: Number of seconds until the JWT expires. If set and non-zero an ``exp`` claim will be added to the payload derived from the current timestamp plus expires_in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_service_account_jwt#expires_in DataGoogleServiceAccountJwt#expires_in}
+        :param id: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_service_account_jwt#id DataGoogleServiceAccountJwt#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
         :param connection: 
         :param count: 
         :param depends_on: 
@@ -84,6 +84,30 @@ class DataGoogleServiceAccountJwt(
 
         jsii.create(self.__class__, self, [scope, id_, config])
 
+    @jsii.member(jsii_name="generateConfigForImport")
+    @builtins.classmethod
+    def generate_config_for_import(
+        cls,
+        scope: _constructs_77d1e7e8.Construct,
+        import_to_id: builtins.str,
+        import_from_id: builtins.str,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    ) -> _cdktf_9a9027ec.ImportableResource:
+        '''Generates CDKTF code for importing a DataGoogleServiceAccountJwt resource upon running "cdktf plan ".
+
+        :param scope: The scope in which to define this construct.
+        :param import_to_id: The construct id used in the generated config for the DataGoogleServiceAccountJwt to import.
+        :param import_from_id: The id of the existing DataGoogleServiceAccountJwt that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_service_account_jwt#import import section} in the documentation of this resource for the id to use
+        :param provider: ? Optional instance of the provider where the DataGoogleServiceAccountJwt to import is found.
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__323baa2a022b113e867b7539ed01cbc08e67a81d5ba27c50b944c7adc3fdeb4f)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument import_to_id", value=import_to_id, expected_type=type_hints["import_to_id"])
+            check_type(argname="argument import_from_id", value=import_from_id, expected_type=type_hints["import_from_id"])
+            check_type(argname="argument provider", value=provider, expected_type=type_hints["provider"])
+        return typing.cast(_cdktf_9a9027ec.ImportableResource, jsii.sinvoke(cls, "generateConfigForImport", [scope, import_to_id, import_from_id, provider]))
+
     @jsii.member(jsii_name="resetDelegates")
     def reset_delegates(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetDelegates", []))
@@ -100,6 +124,10 @@ class DataGoogleServiceAccountJwt(
     def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))
 
+    @jsii.member(jsii_name="synthesizeHclAttributes")
+    def _synthesize_hcl_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
+        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeHclAttributes", []))
+
     @jsii.python.classproperty
     @jsii.member(jsii_name="tfResourceType")
     def TF_RESOURCE_TYPE(cls) -> builtins.str:
@@ -239,11 +267,11 @@ class DataGoogleServiceAccountJwtConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         :param lifecycle: 
         :param provider: 
         :param provisioners: 
-        :param payload: A JSON-encoded JWT claims set that will be included in the signed JWT. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_service_account_jwt#payload DataGoogleServiceAccountJwt#payload}
-        :param target_service_account: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_service_account_jwt#target_service_account DataGoogleServiceAccountJwt#target_service_account}.
-        :param delegates: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_service_account_jwt#delegates DataGoogleServiceAccountJwt#delegates}.
-        :param expires_in: Number of seconds until the JWT expires. If set and non-zero an ``exp`` claim will be added to the payload derived from the current timestamp plus expires_in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_service_account_jwt#expires_in DataGoogleServiceAccountJwt#expires_in}
-        :param id: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_service_account_jwt#id DataGoogleServiceAccountJwt#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
+        :param payload: A JSON-encoded JWT claims set that will be included in the signed JWT. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_service_account_jwt#payload DataGoogleServiceAccountJwt#payload}
+        :param target_service_account: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_service_account_jwt#target_service_account DataGoogleServiceAccountJwt#target_service_account}.
+        :param delegates: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_service_account_jwt#delegates DataGoogleServiceAccountJwt#delegates}.
+        :param expires_in: Number of seconds until the JWT expires. If set and non-zero an ``exp`` claim will be added to the payload derived from the current timestamp plus expires_in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_service_account_jwt#expires_in DataGoogleServiceAccountJwt#expires_in}
+        :param id: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_service_account_jwt#id DataGoogleServiceAccountJwt#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
         '''
         if isinstance(lifecycle, dict):
             lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
@@ -354,7 +382,7 @@ class DataGoogleServiceAccountJwtConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def payload(self) -> builtins.str:
         '''A JSON-encoded JWT claims set that will be included in the signed JWT.
 
-        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_service_account_jwt#payload DataGoogleServiceAccountJwt#payload}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_service_account_jwt#payload DataGoogleServiceAccountJwt#payload}
         '''
         result = self._values.get("payload")
         assert result is not None, "Required property 'payload' is missing"
@@ -362,14 +390,14 @@ class DataGoogleServiceAccountJwtConfig(_cdktf_9a9027ec.TerraformMetaArguments):
 
     @builtins.property
     def target_service_account(self) -> builtins.str:
-        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_service_account_jwt#target_service_account DataGoogleServiceAccountJwt#target_service_account}.'''
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_service_account_jwt#target_service_account DataGoogleServiceAccountJwt#target_service_account}.'''
         result = self._values.get("target_service_account")
         assert result is not None, "Required property 'target_service_account' is missing"
         return typing.cast(builtins.str, result)
 
     @builtins.property
     def delegates(self) -> typing.Optional[typing.List[builtins.str]]:
-        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_service_account_jwt#delegates DataGoogleServiceAccountJwt#delegates}.'''
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_service_account_jwt#delegates DataGoogleServiceAccountJwt#delegates}.'''
         result = self._values.get("delegates")
         return typing.cast(typing.Optional[typing.List[builtins.str]], result)
 
@@ -379,14 +407,14 @@ class DataGoogleServiceAccountJwtConfig(_cdktf_9a9027ec.TerraformMetaArguments):
 
         If set and non-zero an ``exp`` claim will be added to the payload derived from the current timestamp plus expires_in seconds.
 
-        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_service_account_jwt#expires_in DataGoogleServiceAccountJwt#expires_in}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_service_account_jwt#expires_in DataGoogleServiceAccountJwt#expires_in}
         '''
         result = self._values.get("expires_in")
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
     def id(self) -> typing.Optional[builtins.str]:
-        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_service_account_jwt#id DataGoogleServiceAccountJwt#id}.
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/data-sources/google_service_account_jwt#id DataGoogleServiceAccountJwt#id}.
 
         Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
         If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
@@ -433,6 +461,15 @@ def _typecheckingstub__632a6e304332b3ae6a69df691ac01fc655a9339de0e0fd0878ab5a1a6
     """Type checking stubs"""
     pass
 
+def _typecheckingstub__323baa2a022b113e867b7539ed01cbc08e67a81d5ba27c50b944c7adc3fdeb4f(
+    scope: _constructs_77d1e7e8.Construct,
+    import_to_id: builtins.str,
+    import_from_id: builtins.str,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
 def _typecheckingstub__29bcaf37bdc1599d47b8b8d2618a36700b645b2a4fdb81fb479ab23630e5e5dc(
     value: typing.List[builtins.str],
 ) -> None:
