@@ -1,7 +1,7 @@
 '''
 # `google_firestore_index`
 
-Refer to the Terraform Registory for docs: [`google_firestore_index`](https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index).
+Refer to the Terraform Registry for docs: [`google_firestore_index`](https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index).
 '''
 import abc
 import builtins
@@ -26,7 +26,7 @@ class GoogleFirestoreIndex(
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-google-beta.googleFirestoreIndex.GoogleFirestoreIndex",
 ):
-    '''Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index google_firestore_index}.'''
+    '''Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index google_firestore_index}.'''
 
     def __init__(
         self,
@@ -35,6 +35,7 @@ class GoogleFirestoreIndex(
         *,
         collection: builtins.str,
         fields: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["GoogleFirestoreIndexFields", typing.Dict[builtins.str, typing.Any]]]],
+        api_scope: typing.Optional[builtins.str] = None,
         database: typing.Optional[builtins.str] = None,
         id: typing.Optional[builtins.str] = None,
         project: typing.Optional[builtins.str] = None,
@@ -48,17 +49,18 @@ class GoogleFirestoreIndex(
         provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
         provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
-        '''Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index google_firestore_index} Resource.
+        '''Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index google_firestore_index} Resource.
 
         :param scope: The scope in which to define this construct.
         :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
-        :param collection: The collection being indexed. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#collection GoogleFirestoreIndex#collection}
-        :param fields: fields block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#fields GoogleFirestoreIndex#fields}
-        :param database: The Firestore database id. Defaults to '"(default)"'. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#database GoogleFirestoreIndex#database}
-        :param id: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#id GoogleFirestoreIndex#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
-        :param project: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#project GoogleFirestoreIndex#project}.
-        :param query_scope: The scope at which a query is run. Default value: "COLLECTION" Possible values: ["COLLECTION", "COLLECTION_GROUP"]. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#query_scope GoogleFirestoreIndex#query_scope}
-        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#timeouts GoogleFirestoreIndex#timeouts}
+        :param collection: The collection being indexed. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#collection GoogleFirestoreIndex#collection}
+        :param fields: fields block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#fields GoogleFirestoreIndex#fields}
+        :param api_scope: The API scope at which a query is run. Default value: "ANY_API" Possible values: ["ANY_API", "DATASTORE_MODE_API"]. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#api_scope GoogleFirestoreIndex#api_scope}
+        :param database: The Firestore database id. Defaults to '"(default)"'. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#database GoogleFirestoreIndex#database}
+        :param id: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#id GoogleFirestoreIndex#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
+        :param project: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#project GoogleFirestoreIndex#project}.
+        :param query_scope: The scope at which a query is run. Default value: "COLLECTION" Possible values: ["COLLECTION", "COLLECTION_GROUP", "COLLECTION_RECURSIVE"]. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#query_scope GoogleFirestoreIndex#query_scope}
+        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#timeouts GoogleFirestoreIndex#timeouts}
         :param connection: 
         :param count: 
         :param depends_on: 
@@ -74,6 +76,7 @@ class GoogleFirestoreIndex(
         config = GoogleFirestoreIndexConfig(
             collection=collection,
             fields=fields,
+            api_scope=api_scope,
             database=database,
             id=id,
             project=project,
@@ -90,6 +93,30 @@ class GoogleFirestoreIndex(
 
         jsii.create(self.__class__, self, [scope, id_, config])
 
+    @jsii.member(jsii_name="generateConfigForImport")
+    @builtins.classmethod
+    def generate_config_for_import(
+        cls,
+        scope: _constructs_77d1e7e8.Construct,
+        import_to_id: builtins.str,
+        import_from_id: builtins.str,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    ) -> _cdktf_9a9027ec.ImportableResource:
+        '''Generates CDKTF code for importing a GoogleFirestoreIndex resource upon running "cdktf plan ".
+
+        :param scope: The scope in which to define this construct.
+        :param import_to_id: The construct id used in the generated config for the GoogleFirestoreIndex to import.
+        :param import_from_id: The id of the existing GoogleFirestoreIndex that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#import import section} in the documentation of this resource for the id to use
+        :param provider: ? Optional instance of the provider where the GoogleFirestoreIndex to import is found.
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__c774c4e895b1e5397a5865c37f2cdc4a6538a7b6342e403f2d387b1498335fcf)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument import_to_id", value=import_to_id, expected_type=type_hints["import_to_id"])
+            check_type(argname="argument import_from_id", value=import_from_id, expected_type=type_hints["import_from_id"])
+            check_type(argname="argument provider", value=provider, expected_type=type_hints["provider"])
+        return typing.cast(_cdktf_9a9027ec.ImportableResource, jsii.sinvoke(cls, "generateConfigForImport", [scope, import_to_id, import_from_id, provider]))
+
     @jsii.member(jsii_name="putFields")
     def put_fields(
         self,
@@ -111,13 +138,17 @@ class GoogleFirestoreIndex(
         delete: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
-        :param create: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#create GoogleFirestoreIndex#create}.
-        :param delete: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#delete GoogleFirestoreIndex#delete}.
+        :param create: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#create GoogleFirestoreIndex#create}.
+        :param delete: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#delete GoogleFirestoreIndex#delete}.
         '''
         value = GoogleFirestoreIndexTimeouts(create=create, delete=delete)
 
         return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))
 
+    @jsii.member(jsii_name="resetApiScope")
+    def reset_api_scope(self) -> None:
+        return typing.cast(None, jsii.invoke(self, "resetApiScope", []))
+
     @jsii.member(jsii_name="resetDatabase")
     def reset_database(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetDatabase", []))
@@ -142,6 +173,10 @@ class GoogleFirestoreIndex(
     def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))
 
+    @jsii.member(jsii_name="synthesizeHclAttributes")
+    def _synthesize_hcl_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
+        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeHclAttributes", []))
+
     @jsii.python.classproperty
     @jsii.member(jsii_name="tfResourceType")
     def TF_RESOURCE_TYPE(cls) -> builtins.str:
@@ -162,6 +197,11 @@ class GoogleFirestoreIndex(
     def timeouts(self) -> "GoogleFirestoreIndexTimeoutsOutputReference":
         return typing.cast("GoogleFirestoreIndexTimeoutsOutputReference", jsii.get(self, "timeouts"))
 
+    @builtins.property
+    @jsii.member(jsii_name="apiScopeInput")
+    def api_scope_input(self) -> typing.Optional[builtins.str]:
+        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "apiScopeInput"))
+
     @builtins.property
     @jsii.member(jsii_name="collectionInput")
     def collection_input(self) -> typing.Optional[builtins.str]:
@@ -198,8 +238,20 @@ class GoogleFirestoreIndex(
     @jsii.member(jsii_name="timeoutsInput")
     def timeouts_input(
         self,
-    ) -> typing.Optional[typing.Union["GoogleFirestoreIndexTimeouts", _cdktf_9a9027ec.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union["GoogleFirestoreIndexTimeouts", _cdktf_9a9027ec.IResolvable]], jsii.get(self, "timeoutsInput"))
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, "GoogleFirestoreIndexTimeouts"]]:
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, "GoogleFirestoreIndexTimeouts"]], jsii.get(self, "timeoutsInput"))
+
+    @builtins.property
+    @jsii.member(jsii_name="apiScope")
+    def api_scope(self) -> builtins.str:
+        return typing.cast(builtins.str, jsii.get(self, "apiScope"))
+
+    @api_scope.setter
+    def api_scope(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__568d4be98bf92779ddc662959a91c89ef2bfe40eeff53065362e7cd3a04efa1b)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "apiScope", value)
 
     @builtins.property
     @jsii.member(jsii_name="collection")
@@ -275,6 +327,7 @@ class GoogleFirestoreIndex(
         "provisioners": "provisioners",
         "collection": "collection",
         "fields": "fields",
+        "api_scope": "apiScope",
         "database": "database",
         "id": "id",
         "project": "project",
@@ -295,6 +348,7 @@ class GoogleFirestoreIndexConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         collection: builtins.str,
         fields: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["GoogleFirestoreIndexFields", typing.Dict[builtins.str, typing.Any]]]],
+        api_scope: typing.Optional[builtins.str] = None,
         database: typing.Optional[builtins.str] = None,
         id: typing.Optional[builtins.str] = None,
         project: typing.Optional[builtins.str] = None,
@@ -309,13 +363,14 @@ class GoogleFirestoreIndexConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         :param lifecycle: 
         :param provider: 
         :param provisioners: 
-        :param collection: The collection being indexed. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#collection GoogleFirestoreIndex#collection}
-        :param fields: fields block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#fields GoogleFirestoreIndex#fields}
-        :param database: The Firestore database id. Defaults to '"(default)"'. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#database GoogleFirestoreIndex#database}
-        :param id: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#id GoogleFirestoreIndex#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
-        :param project: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#project GoogleFirestoreIndex#project}.
-        :param query_scope: The scope at which a query is run. Default value: "COLLECTION" Possible values: ["COLLECTION", "COLLECTION_GROUP"]. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#query_scope GoogleFirestoreIndex#query_scope}
-        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#timeouts GoogleFirestoreIndex#timeouts}
+        :param collection: The collection being indexed. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#collection GoogleFirestoreIndex#collection}
+        :param fields: fields block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#fields GoogleFirestoreIndex#fields}
+        :param api_scope: The API scope at which a query is run. Default value: "ANY_API" Possible values: ["ANY_API", "DATASTORE_MODE_API"]. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#api_scope GoogleFirestoreIndex#api_scope}
+        :param database: The Firestore database id. Defaults to '"(default)"'. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#database GoogleFirestoreIndex#database}
+        :param id: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#id GoogleFirestoreIndex#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
+        :param project: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#project GoogleFirestoreIndex#project}.
+        :param query_scope: The scope at which a query is run. Default value: "COLLECTION" Possible values: ["COLLECTION", "COLLECTION_GROUP", "COLLECTION_RECURSIVE"]. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#query_scope GoogleFirestoreIndex#query_scope}
+        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#timeouts GoogleFirestoreIndex#timeouts}
         '''
         if isinstance(lifecycle, dict):
             lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
@@ -332,6 +387,7 @@ class GoogleFirestoreIndexConfig(_cdktf_9a9027ec.TerraformMetaArguments):
             check_type(argname="argument provisioners", value=provisioners, expected_type=type_hints["provisioners"])
             check_type(argname="argument collection", value=collection, expected_type=type_hints["collection"])
             check_type(argname="argument fields", value=fields, expected_type=type_hints["fields"])
+            check_type(argname="argument api_scope", value=api_scope, expected_type=type_hints["api_scope"])
             check_type(argname="argument database", value=database, expected_type=type_hints["database"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument project", value=project, expected_type=type_hints["project"])
@@ -355,6 +411,8 @@ class GoogleFirestoreIndexConfig(_cdktf_9a9027ec.TerraformMetaArguments):
             self._values["provider"] = provider
         if provisioners is not None:
             self._values["provisioners"] = provisioners
+        if api_scope is not None:
+            self._values["api_scope"] = api_scope
         if database is not None:
             self._values["database"] = database
         if id is not None:
@@ -434,7 +492,7 @@ class GoogleFirestoreIndexConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def collection(self) -> builtins.str:
         '''The collection being indexed.
 
-        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#collection GoogleFirestoreIndex#collection}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#collection GoogleFirestoreIndex#collection}
         '''
         result = self._values.get("collection")
         assert result is not None, "Required property 'collection' is missing"
@@ -446,24 +504,33 @@ class GoogleFirestoreIndexConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     ) -> typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["GoogleFirestoreIndexFields"]]:
         '''fields block.
 
-        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#fields GoogleFirestoreIndex#fields}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#fields GoogleFirestoreIndex#fields}
         '''
         result = self._values.get("fields")
         assert result is not None, "Required property 'fields' is missing"
         return typing.cast(typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["GoogleFirestoreIndexFields"]], result)
 
+    @builtins.property
+    def api_scope(self) -> typing.Optional[builtins.str]:
+        '''The API scope at which a query is run. Default value: "ANY_API" Possible values: ["ANY_API", "DATASTORE_MODE_API"].
+
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#api_scope GoogleFirestoreIndex#api_scope}
+        '''
+        result = self._values.get("api_scope")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     @builtins.property
     def database(self) -> typing.Optional[builtins.str]:
         '''The Firestore database id. Defaults to '"(default)"'.
 
-        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#database GoogleFirestoreIndex#database}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#database GoogleFirestoreIndex#database}
         '''
         result = self._values.get("database")
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
     def id(self) -> typing.Optional[builtins.str]:
-        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#id GoogleFirestoreIndex#id}.
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#id GoogleFirestoreIndex#id}.
 
         Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
         If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
@@ -473,15 +540,15 @@ class GoogleFirestoreIndexConfig(_cdktf_9a9027ec.TerraformMetaArguments):
 
     @builtins.property
     def project(self) -> typing.Optional[builtins.str]:
-        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#project GoogleFirestoreIndex#project}.'''
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#project GoogleFirestoreIndex#project}.'''
         result = self._values.get("project")
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
     def query_scope(self) -> typing.Optional[builtins.str]:
-        '''The scope at which a query is run. Default value: "COLLECTION" Possible values: ["COLLECTION", "COLLECTION_GROUP"].
+        '''The scope at which a query is run. Default value: "COLLECTION" Possible values: ["COLLECTION", "COLLECTION_GROUP", "COLLECTION_RECURSIVE"].
 
-        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#query_scope GoogleFirestoreIndex#query_scope}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#query_scope GoogleFirestoreIndex#query_scope}
         '''
         result = self._values.get("query_scope")
         return typing.cast(typing.Optional[builtins.str], result)
@@ -490,7 +557,7 @@ class GoogleFirestoreIndexConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def timeouts(self) -> typing.Optional["GoogleFirestoreIndexTimeouts"]:
         '''timeouts block.
 
-        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#timeouts GoogleFirestoreIndex#timeouts}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#timeouts GoogleFirestoreIndex#timeouts}
         '''
         result = self._values.get("timeouts")
         return typing.cast(typing.Optional["GoogleFirestoreIndexTimeouts"], result)
@@ -525,9 +592,9 @@ class GoogleFirestoreIndexFields:
         order: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
-        :param array_config: Indicates that this field supports operations on arrayValues. Only one of 'order' and 'arrayConfig' can be specified. Possible values: ["CONTAINS"]. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#array_config GoogleFirestoreIndex#array_config}
-        :param field_path: Name of the field. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#field_path GoogleFirestoreIndex#field_path}
-        :param order: Indicates that this field supports ordering by the specified order or comparing using =, <, <=, >, >=. Only one of 'order' and 'arrayConfig' can be specified. Possible values: ["ASCENDING", "DESCENDING"] Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#order GoogleFirestoreIndex#order}
+        :param array_config: Indicates that this field supports operations on arrayValues. Only one of 'order' and 'arrayConfig' can be specified. Possible values: ["CONTAINS"]. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#array_config GoogleFirestoreIndex#array_config}
+        :param field_path: Name of the field. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#field_path GoogleFirestoreIndex#field_path}
+        :param order: Indicates that this field supports ordering by the specified order or comparing using =, <, <=, >, >=. Only one of 'order' and 'arrayConfig' can be specified. Possible values: ["ASCENDING", "DESCENDING"] Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#order GoogleFirestoreIndex#order}
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__86e1e1ba632071e509d21d78517f2cdec76434d473db8b3f51b42cc62dd48c88)
@@ -546,7 +613,7 @@ class GoogleFirestoreIndexFields:
     def array_config(self) -> typing.Optional[builtins.str]:
         '''Indicates that this field supports operations on arrayValues. Only one of 'order' and 'arrayConfig' can be specified. Possible values: ["CONTAINS"].
 
-        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#array_config GoogleFirestoreIndex#array_config}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#array_config GoogleFirestoreIndex#array_config}
         '''
         result = self._values.get("array_config")
         return typing.cast(typing.Optional[builtins.str], result)
@@ -555,7 +622,7 @@ class GoogleFirestoreIndexFields:
     def field_path(self) -> typing.Optional[builtins.str]:
         '''Name of the field.
 
-        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#field_path GoogleFirestoreIndex#field_path}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#field_path GoogleFirestoreIndex#field_path}
         '''
         result = self._values.get("field_path")
         return typing.cast(typing.Optional[builtins.str], result)
@@ -566,7 +633,7 @@ class GoogleFirestoreIndexFields:
 
         Only one of 'order' and 'arrayConfig' can be specified. Possible values: ["ASCENDING", "DESCENDING"]
 
-        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#order GoogleFirestoreIndex#order}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#order GoogleFirestoreIndex#order}
         '''
         result = self._values.get("order")
         return typing.cast(typing.Optional[builtins.str], result)
@@ -766,13 +833,13 @@ class GoogleFirestoreIndexFieldsOutputReference(
     @jsii.member(jsii_name="internalValue")
     def internal_value(
         self,
-    ) -> typing.Optional[typing.Union[GoogleFirestoreIndexFields, _cdktf_9a9027ec.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[GoogleFirestoreIndexFields, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "internalValue"))
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, GoogleFirestoreIndexFields]]:
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, GoogleFirestoreIndexFields]], jsii.get(self, "internalValue"))
 
     @internal_value.setter
     def internal_value(
         self,
-        value: typing.Optional[typing.Union[GoogleFirestoreIndexFields, _cdktf_9a9027ec.IResolvable]],
+        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, GoogleFirestoreIndexFields]],
     ) -> None:
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__f468da1a7f2f272f6f8e6e375f61acfe77a32cb51724a716a39d1499705c8b1d)
@@ -793,8 +860,8 @@ class GoogleFirestoreIndexTimeouts:
         delete: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
-        :param create: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#create GoogleFirestoreIndex#create}.
-        :param delete: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#delete GoogleFirestoreIndex#delete}.
+        :param create: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#create GoogleFirestoreIndex#create}.
+        :param delete: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#delete GoogleFirestoreIndex#delete}.
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__f5b0eea42a80637a7076c51c0b5fd1dd232e563b75133c39295312e63b3005b1)
@@ -808,13 +875,13 @@ class GoogleFirestoreIndexTimeouts:
 
     @builtins.property
     def create(self) -> typing.Optional[builtins.str]:
-        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#create GoogleFirestoreIndex#create}.'''
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#create GoogleFirestoreIndex#create}.'''
         result = self._values.get("create")
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
     def delete(self) -> typing.Optional[builtins.str]:
-        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_firestore_index#delete GoogleFirestoreIndex#delete}.'''
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.21.0/docs/resources/google_firestore_index#delete GoogleFirestoreIndex#delete}.'''
         result = self._values.get("delete")
         return typing.cast(typing.Optional[builtins.str], result)
 
@@ -896,13 +963,13 @@ class GoogleFirestoreIndexTimeoutsOutputReference(
     @jsii.member(jsii_name="internalValue")
     def internal_value(
         self,
-    ) -> typing.Optional[typing.Union[GoogleFirestoreIndexTimeouts, _cdktf_9a9027ec.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[GoogleFirestoreIndexTimeouts, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "internalValue"))
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, GoogleFirestoreIndexTimeouts]]:
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, GoogleFirestoreIndexTimeouts]], jsii.get(self, "internalValue"))
 
     @internal_value.setter
     def internal_value(
         self,
-        value: typing.Optional[typing.Union[GoogleFirestoreIndexTimeouts, _cdktf_9a9027ec.IResolvable]],
+        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, GoogleFirestoreIndexTimeouts]],
     ) -> None:
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__255faa5434e972f30d6ac1ffc632200a12c46124e18f65790d127a2442e5d702)
@@ -928,6 +995,7 @@ def _typecheckingstub__e60963a46756a43e79cc95b8a8f15ac88c5e3d8736ac95cd9cf95897a
     *,
     collection: builtins.str,
     fields: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[GoogleFirestoreIndexFields, typing.Dict[builtins.str, typing.Any]]]],
+    api_scope: typing.Optional[builtins.str] = None,
     database: typing.Optional[builtins.str] = None,
     id: typing.Optional[builtins.str] = None,
     project: typing.Optional[builtins.str] = None,
@@ -944,12 +1012,27 @@ def _typecheckingstub__e60963a46756a43e79cc95b8a8f15ac88c5e3d8736ac95cd9cf95897a
     """Type checking stubs"""
     pass
 
+def _typecheckingstub__c774c4e895b1e5397a5865c37f2cdc4a6538a7b6342e403f2d387b1498335fcf(
+    scope: _constructs_77d1e7e8.Construct,
+    import_to_id: builtins.str,
+    import_from_id: builtins.str,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
 def _typecheckingstub__00814786f7195b76a8676961b24388072df36a14822d3a8505de3cc941beb909(
     value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[GoogleFirestoreIndexFields, typing.Dict[builtins.str, typing.Any]]]],
 ) -> None:
     """Type checking stubs"""
     pass
 
+def _typecheckingstub__568d4be98bf92779ddc662959a91c89ef2bfe40eeff53065362e7cd3a04efa1b(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
 def _typecheckingstub__84755741bc5447063f0e1c2cb06e427a272f6f1669580cf15975155c81a0daff(
     value: builtins.str,
 ) -> None:
@@ -991,6 +1074,7 @@ def _typecheckingstub__f2f46115e8c1dbded35dc06f90020258b9f5909780238cde332b022ac
     provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     collection: builtins.str,
     fields: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[GoogleFirestoreIndexFields, typing.Dict[builtins.str, typing.Any]]]],
+    api_scope: typing.Optional[builtins.str] = None,
     database: typing.Optional[builtins.str] = None,
     id: typing.Optional[builtins.str] = None,
     project: typing.Optional[builtins.str] = None,
@@ -1075,7 +1159,7 @@ def _typecheckingstub__0ea5e5c03cbaf0ba55c581eeb46327cd28fa443df66d41f5cd0a22586
     pass
 
 def _typecheckingstub__f468da1a7f2f272f6f8e6e375f61acfe77a32cb51724a716a39d1499705c8b1d(
-    value: typing.Optional[typing.Union[GoogleFirestoreIndexFields, _cdktf_9a9027ec.IResolvable]],
+    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, GoogleFirestoreIndexFields]],
 ) -> None:
     """Type checking stubs"""
     pass
@@ -1108,7 +1192,7 @@ def _typecheckingstub__8c41174305411b8b25f30cc7e91076913a887589b0a5809cea1939c27
     pass
 
 def _typecheckingstub__255faa5434e972f30d6ac1ffc632200a12c46124e18f65790d127a2442e5d702(
-    value: typing.Optional[typing.Union[GoogleFirestoreIndexTimeouts, _cdktf_9a9027ec.IResolvable]],
+    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, GoogleFirestoreIndexTimeouts]],
 ) -> None:
     """Type checking stubs"""
     pass
